@@ -6,16 +6,16 @@ The |Table| object and related proxy classes.
 
 from __future__ import absolute_import, print_function, unicode_literals
 
-from .shared import lazyproperty, write_only_property
+from .shared import lazyproperty, Parented, write_only_property
 from .text import Paragraph
 
 
-class Table(object):
+class Table(Parented):
     """
     Proxy class for a WordprocessingML ``<w:tbl>`` element.
     """
-    def __init__(self, tbl):
-        super(Table, self).__init__()
+    def __init__(self, tbl, parent):
+        super(Table, self).__init__(parent)
         self._tbl = tbl
 
     def add_column(self):
@@ -26,7 +26,7 @@ class Table(object):
         gridCol = tblGrid.add_gridCol()
         for tr in self._tbl.tr_lst:
             tr.add_tc()
-        return _Column(gridCol, self._tbl)
+        return _Column(gridCol, self._tbl, self)
 
     def add_row(self):
         """
@@ -36,7 +36,7 @@ class Table(object):
         tr = tbl.add_tr()
         for gridCol in tbl.tblGrid.gridCol_lst:
             tr.add_tc()
-        return _Row(tr)
+        return _Row(tr, self)
 
     def cell(self, row_idx, col_idx):
         """
@@ -51,14 +51,14 @@ class Table(object):
         """
         |_Columns| instance containing the sequence of rows in this table.
         """
-        return _Columns(self._tbl)
+        return _Columns(self._tbl, self)
 
     @lazyproperty
     def rows(self):
         """
         |_Rows| instance containing the sequence of rows in this table.
         """
-        return _Rows(self._tbl)
+        return _Rows(self._tbl, self)
 
     @property
     def style(self):
@@ -67,30 +67,23 @@ class Table(object):
         'LightShading-Accent1'. Name is derived by removing spaces from the
         table style name displayed in the Word UI.
         """
-        tblStyle = self._tblPr.tblStyle
-        if tblStyle is None:
-            return None
-        return tblStyle.val
+        return self._tblPr.style
 
     @style.setter
-    def style(self, style_name):
-        tblStyle = self._tblPr.tblStyle
-        if tblStyle is None:
-            self._tblPr.add_tblStyle(style_name)
-        else:
-            tblStyle.val = style_name
+    def style(self, value):
+        self._tblPr.style = value
 
     @property
     def _tblPr(self):
         return self._tbl.tblPr
 
 
-class _Cell(object):
+class _Cell(Parented):
     """
     Table cell
     """
-    def __init__(self, tc):
-        super(_Cell, self).__init__()
+    def __init__(self, tc, parent):
+        super(_Cell, self).__init__(parent)
         self._tc = tc
 
     @property
@@ -100,7 +93,7 @@ class _Cell(object):
         at least one block-level element. By default this is a single
         paragraph.
         """
-        return [Paragraph(p) for p in self._tc.p_lst]
+        return [Paragraph(p, self) for p in self._tc.p_lst]
 
     @write_only_property
     def text(self, text):
@@ -115,12 +108,12 @@ class _Cell(object):
         r.text = text
 
 
-class _Column(object):
+class _Column(Parented):
     """
     Table column
     """
-    def __init__(self, gridCol, tbl):
-        super(_Column, self).__init__()
+    def __init__(self, gridCol, tbl, parent):
+        super(_Column, self).__init__(parent)
         self._gridCol = gridCol
         self._tbl = tbl
 
@@ -130,7 +123,7 @@ class _Column(object):
         Sequence of |_Cell| instances corresponding to cells in this column.
         Supports ``len()``, iteration and indexed access.
         """
-        return _ColumnCells(self._tbl, self._gridCol)
+        return _ColumnCells(self._tbl, self._gridCol, self)
 
     @property
     def width(self):
@@ -145,13 +138,13 @@ class _Column(object):
         self._gridCol.w = value
 
 
-class _ColumnCells(object):
+class _ColumnCells(Parented):
     """
     Sequence of |_Cell| instances corresponding to the cells in a table
     column.
     """
-    def __init__(self, tbl, gridCol):
-        super(_ColumnCells, self).__init__()
+    def __init__(self, tbl, gridCol, parent):
+        super(_ColumnCells, self).__init__(parent)
         self._tbl = tbl
         self._gridCol = gridCol
 
@@ -165,12 +158,12 @@ class _ColumnCells(object):
             msg = "cell index [%d] is out of range" % idx
             raise IndexError(msg)
         tc = tr.tc_lst[self._col_idx]
-        return _Cell(tc)
+        return _Cell(tc, self)
 
     def __iter__(self):
         for tr in self._tr_lst:
             tc = tr.tc_lst[self._col_idx]
-            yield _Cell(tc)
+            yield _Cell(tc, self)
 
     def __len__(self):
         return len(self._tr_lst)
@@ -185,13 +178,13 @@ class _ColumnCells(object):
         return self._tbl.tr_lst
 
 
-class _Columns(object):
+class _Columns(Parented):
     """
     Sequence of |_Column| instances corresponding to the columns in a table.
     Supports ``len()``, iteration and indexed access.
     """
-    def __init__(self, tbl):
-        super(_Columns, self).__init__()
+    def __init__(self, tbl, parent):
+        super(_Columns, self).__init__(parent)
         self._tbl = tbl
 
     def __getitem__(self, idx):
@@ -203,10 +196,11 @@ class _Columns(object):
         except IndexError:
             msg = "column index [%d] is out of range" % idx
             raise IndexError(msg)
-        return _Column(gridCol, self._tbl)
+        return _Column(gridCol, self._tbl, self)
 
     def __iter__(self):
-        return (_Column(gridCol, self._tbl) for gridCol in self._gridCol_lst)
+        for gridCol in self._gridCol_lst:
+            yield _Column(gridCol, self._tbl, self)
 
     def __len__(self):
         return len(self._gridCol_lst)
@@ -221,12 +215,12 @@ class _Columns(object):
         return tblGrid.gridCol_lst
 
 
-class _Row(object):
+class _Row(Parented):
     """
     Table row
     """
-    def __init__(self, tr):
-        super(_Row, self).__init__()
+    def __init__(self, tr, parent):
+        super(_Row, self).__init__(parent)
         self._tr = tr
 
     @lazyproperty
@@ -235,15 +229,15 @@ class _Row(object):
         Sequence of |_Cell| instances corresponding to cells in this row.
         Supports ``len()``, iteration and indexed access.
         """
-        return _RowCells(self._tr)
+        return _RowCells(self._tr, self)
 
 
-class _RowCells(object):
+class _RowCells(Parented):
     """
     Sequence of |_Cell| instances corresponding to the cells in a table row.
     """
-    def __init__(self, tr):
-        super(_RowCells, self).__init__()
+    def __init__(self, tr, parent):
+        super(_RowCells, self).__init__(parent)
         self._tr = tr
 
     def __getitem__(self, idx):
@@ -255,22 +249,22 @@ class _RowCells(object):
         except IndexError:
             msg = "cell index [%d] is out of range" % idx
             raise IndexError(msg)
-        return _Cell(tc)
+        return _Cell(tc, self)
 
     def __iter__(self):
-        return (_Cell(tc) for tc in self._tr.tc_lst)
+        return (_Cell(tc, self) for tc in self._tr.tc_lst)
 
     def __len__(self):
         return len(self._tr.tc_lst)
 
 
-class _Rows(object):
+class _Rows(Parented):
     """
     Sequence of |_Row| instances corresponding to the rows in a table.
     Supports ``len()``, iteration and indexed access.
     """
-    def __init__(self, tbl):
-        super(_Rows, self).__init__()
+    def __init__(self, tbl, parent):
+        super(_Rows, self).__init__(parent)
         self._tbl = tbl
 
     def __getitem__(self, idx):
@@ -282,10 +276,10 @@ class _Rows(object):
         except IndexError:
             msg = "row index [%d] out of range" % idx
             raise IndexError(msg)
-        return _Row(tr)
+        return _Row(tr, self)
 
     def __iter__(self):
-        return (_Row(tr) for tr in self._tbl.tr_lst)
+        return (_Row(tr, self) for tr in self._tbl.tr_lst)
 
     def __len__(self):
         return len(self._tbl.tr_lst)
